@@ -20,6 +20,7 @@ def load_actual_building_data(buildings,observer,weather,forecast,date,res):
             actual_data['loads'] = [{} for i in range(n_b)]
             actual_data['gains'] = [{} for i in range(n_b)]
             actual_data['S'] = [[] for i in range(n_b)]
+            actual_data['water_heat'] = [[] for i in range(n_b)]
             actual_data['Tz_nominal'] = [[] for i in range(n_b)]
             actual_data['T_avg'] = [[] for i in range(n_b)]
             actual_data['E0'] = [forecast['E0'][0]]
@@ -30,7 +31,7 @@ def load_actual_building_data(buildings,observer,weather,forecast,date,res):
                 T_zone = observer['building_zone_temp'][i]
                 frost = observer['building_frost'][i]
                 schedules = load_sched(bldg['schedule'], bldg['holidays'], date, None, False)#can replace with modified schedules
-                loads, gains, _, _, _, _, _, _, _ = zone_loads(bldg, date[0], schedules, weather_now, T_zone, humidity, res, frost)
+                loads, gains, _, _, _, _, _, _, water_heat = zone_loads(bldg, date[0], schedules, weather_now, T_zone, humidity, res, frost)
                 actual_gains = [internal_gain_scalar[i][j]*g for j,g in enumerate(loads['internal_gain'])]
                 new_loads, new_gains,S = update_real_gains(bldg, weather_now, loads, gains, date[0], actual_gains)
                 actual_data['loads'][i] = {}
@@ -53,6 +54,7 @@ def load_actual_building_data(buildings,observer,weather,forecast,date,res):
                     else:
                         actual_data['gains'][i][k] = new_gains[k]+0
                 actual_data['S'][i] = [[j for j in w] for w in S]
+                actual_data['water_heat'][i] = water_heat
                 actual_data['Tz_nominal'][i] = [j for j in forecast['Tz_nominal'][i]]
                 actual_data['T_avg'][i] = [area_weighted_temperature(bldg,actual_data['Tz_nominal'][i])]
     else:
